/*!
 * レス数でグループ化して多い順に並べる
 * 
 * @include "janescript/JaneScript.js"
 */
(function(){
	var title = "レス数でグループ化";
	
	/**
	 * @param {_JVS.ThreadItem} thread
	 */
	function sortByRefCount(thread){
		if (!thread) return;
		
		var refs = thread.GetReferredList();
		var groups = [];
		
		for(var i=1; i<= thread.Lines; i++){
			var res = thread.GetRes(i);
			var refCount = refs.RefCount(i);
			var group;
			if(groups[refCount]){
				group = groups[refCount];
			}else{
				group = [];
				groups[refCount] = group;
			}
			group.push(i);//res.Number の数値がおかしい
		}
		
		var newView = JaneScript.ViewList().NewView(false, false);
		try {
			newView.TabText = title;
			newView.ExtraTitle = title + ": " + thread.Title;
			var datOut = newView.QueryDatOut();
			newView.WriteSkin("");
			
			for(var refCount = groups.length; refCount >= 0; refCount--){
				var group = groups[refCount];
				if(!group) continue;
				datOut.WriteBR();
				datOut.WriteText("==== " + refCount + " (" + group.length + ") ====");
				datOut.WriteBR();
				for(var i=0; i<group.length; i++){
					var num = group[i];
					datOut.WriteHTML('<a href="' + thread.URL + num + '">' + num + '</a> ');
				}
			}
		} catch(e) {
			if ((e.number & 0xFFFF) != 0x8001){
				//0x8001は処理中にviewItemが閉じられると発生する
				throw e; //0x8001以外の場合は何か別のエラーなので例外を再生成
			}
		} finally {
			if (newView.Connected){
				newView.EndDatOut(); //書き出し終了時はEndDatOutを呼び出す
			}
		};
	}
	
	//検索メニューの一番下にメニューアイテムを追加
	var menu1 = JaneScript.InsertMenu("MainWnd.MainMenu", "Find1", 1000);
	menu1.Caption = title;
	menu1.OnClick = function(m, t){
		var activeView = JaneScript.ActiveView();
		if(activeView){
			sortByRefCount(activeView.Thread());
		}
	};
	
	//スレタブ右クリックメニューの一番下にメニューアイテムを追加
	var menu2 = JaneScript.InsertMenu("MainWnd.ThreadPopupMenu", "", 1000);
	menu2.Caption = title;
	menu2.OnClick = function(m, t){
		if("ViewItem" === t.ObjectName){
			var viewItem = t.PopupObject;
			if(viewItem){
				sortByRefCount(viewItem.Thread());
			}
		}
	};
})();

